AddressServiceBase class abstract

Annotations
  • @GrpcServiceName.new('emerald.Address')

Constructors

AddressServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
describe(ServiceCall call, DescribeRequest request) Future<DescribeResponse>
describe_Pre(ServiceCall $call, Future<DescribeRequest> $request) Future<DescribeResponse>
describeXpub(ServiceCall call, DescribeXpubRequest request) Future<DescribeXpubResponse>
describeXpub_Pre(ServiceCall $call, Future<DescribeXpubRequest> $request) Future<DescribeXpubResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited