AuthServiceBase class abstract

Annotations
  • @GrpcServiceName.new('emerald.Auth')

Constructors

AuthServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
authenticate(ServiceCall call, AuthRequest request) Future<AuthResponse>
authenticate_Pre(ServiceCall $call, Future<AuthRequest> $request) Future<AuthResponse>
deleteToken(ServiceCall call, DeleteTokenRequest request) Future<DeleteTokenResponse>
deleteToken_Pre(ServiceCall $call, Future<DeleteTokenRequest> $request) Future<DeleteTokenResponse>
issueToken(ServiceCall call, IssueTokenRequest request) Future<IssuedTokenResponse>
issueToken_Pre(ServiceCall $call, Future<IssueTokenRequest> $request) Future<IssuedTokenResponse>
listTokens(ServiceCall call, ListTokensRequest request) Future<ListTokensResponse>
listTokens_Pre(ServiceCall $call, Future<ListTokensRequest> $request) Future<ListTokensResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refresh(ServiceCall call, RefreshRequest request) Future<AuthResponse>
refresh_Pre(ServiceCall $call, Future<RefreshRequest> $request) Future<AuthResponse>
toString() String
A string representation of this object.
inherited
whoAmI(ServiceCall call, WhoAmIRequest request) Future<WhoAmIResponse>
whoAmI_Pre(ServiceCall $call, Future<WhoAmIRequest> $request) Future<WhoAmIResponse>

Operators

operator ==(Object other) bool
The equality operator.
inherited