IssueTokenRequest_TokenType class

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) IssueTokenRequest_TokenType?

Constants

PERMANENT → const IssueTokenRequest_TokenType
a token that is valid for a long period of time, multiple sessions and associated with a project for stats and billing
TEMP → const IssueTokenRequest_TokenType
a one-time token that is valid for a short period of time, just a reference to the current token for one time and exclusive session but may be limited by time, scope, etc. expires after first use.
values → const List<IssueTokenRequest_TokenType>