PERMANENT constant

IssueTokenRequest_TokenType const PERMANENT

a token that is valid for a long period of time, multiple sessions and associated with a project for stats and billing

Implementation

static const IssueTokenRequest_TokenType PERMANENT =
    IssueTokenRequest_TokenType._(1, _omitEnumNames ? '' : 'PERMANENT');