BlockchainClient class

Annotations
  • @GrpcServiceName.new('emerald.Blockchain')

Constructors

BlockchainClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
describe(DescribeRequest request, {CallOptions? options}) → ResponseFuture<DescribeResponse>
estimateFee(EstimateFeeRequest request, {CallOptions? options}) → ResponseFuture<EstimateFeeResponse>
  • getAddressAllowance(AddressAllowanceRequest request, {CallOptions? options}) → ResponseStream<AddressAllowance>
    DEPRECATED, moved to token service
    getBalance(BalanceRequest request, {CallOptions? options}) → ResponseStream<AddressBalance>
    nativeCall(NativeCallRequest request, {CallOptions? options}) → ResponseStream<NativeCallReplyItem>
    nativeSubscribe(NativeSubscribeRequest request, {CallOptions? options}) → ResponseStream<NativeSubscribeReplyItem>
    noSuchMethod(Invocation invocation) → dynamic
    Invoked when a nonexistent method or property is accessed.
    inherited
    subscribeAddressAllowance(AddressAllowanceRequest request, {CallOptions? options}) → ResponseStream<AddressAllowance>
    DEPRECATED, moved to token service
    subscribeBalance(BalanceRequest request, {CallOptions? options}) → ResponseStream<AddressBalance>
    subscribeHead(Chain request, {CallOptions? options}) → ResponseStream<ChainHead>
    subscribeStatus(StatusRequest request, {CallOptions? options}) → ResponseStream<ChainStatus>
    subscribeTxStatus(TxStatusRequest request, {CallOptions? options}) → ResponseStream<TxStatus>
    toString() String
    A string representation of this object.
    inherited

    Operators

    operator ==(Object other) bool
    The equality operator.
    inherited

    Constants

    defaultHost → const String
    The hostname for this service.
    oauthScopes → const List<String>
    OAuth scopes needed for the client.