blocks property

  1. @TagNumber.new(3)
int get blocks

How many blocks the server is supposed to use to estimate current fee. Note that the server may use value, depending on configuration

Implementation

@$pb.TagNumber(3)
$core.int get blocks => $_getIZ(2);
  1. @TagNumber.new(3)
set blocks (int value)

Implementation

@$pb.TagNumber(3)
set blocks($core.int value) => $_setUnsignedInt32(2, value);