max property

  1. @TagNumber.new(3)
String get max

Big Number encoded as string. Max Fee value in Wei. Note that it only indicates the current preference, and the actual Max may be significantly lower, depending on the usage scenario.

Implementation

@$pb.TagNumber(3)
$core.String get max => $_getSZ(2);
  1. @TagNumber.new(3)
set max (String value)

Implementation

@$pb.TagNumber(3)
set max($core.String value) => $_setString(2, value);