FeeEstimationMode class

The mode of how the fee must be estimated

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) FeeEstimationMode?

Constants

AVG_LAST → const FeeEstimationMode
Average over last transaction in each block
AVG_MIDDLE → const FeeEstimationMode
Average over transaction in the middle of each block
AVG_T5 → const FeeEstimationMode
Average over transaction 5th from the end in each block
AVG_T20 → const FeeEstimationMode
Average over transaction 20th from the end in each block
AVG_T50 → const FeeEstimationMode
Average over transaction 50th from the end in each block
AVG_TOP → const FeeEstimationMode
Average over transaction in head of each block. Note that for Bitcoin it doesn't count COINBASE tx as top tx.
INVALID → const FeeEstimationMode
MIN_ALWAYS → const FeeEstimationMode
Minimal fee that would be accepted by every last block
values → const List<FeeEstimationMode>