counts property
request counts for the requested period, split according to precision, including zero values
Implementation
@$pb.TagNumber(3)
$pb.PbList<RequestCount> get counts => $_getList(2);
request counts for the requested period, split according to precision, including zero values
@$pb.TagNumber(3)
$pb.PbList<RequestCount> get counts => $_getList(2);