ProjectServiceBase class abstract

Annotations
  • @GrpcServiceName.new('emerald.sierra.Project')

Constructors

ProjectServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
createProject(ServiceCall call, CreateProjectRequest request) Future<Project>
createProject_Pre(ServiceCall $call, Future<CreateProjectRequest> $request) Future<Project>
listProjects(ServiceCall call, ListProjectsRequest request) Stream<Project>
listProjects_Pre(ServiceCall $call, Future<ListProjectsRequest> $request) Stream<Project>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited