StatServiceBase class abstract

Annotations
  • @GrpcServiceName.new('emerald.sierra.Stat')

Constructors

StatServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
getRequestCount(ServiceCall call, GetRequestCountRequest request) Stream<GroupRequestCount>
getRequestCount_Pre(ServiceCall $call, Future<GetRequestCountRequest> $request) Stream<GroupRequestCount>
getTokenStat(ServiceCall call, GetTokenStatRequest request) Stream<TokenStat>
getTokenStat_Pre(ServiceCall $call, Future<GetTokenStatRequest> $request) Stream<TokenStat>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited