TokenClient class

Annotations
  • @GrpcServiceName.new('emerald.Token')

Constructors

TokenClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
getAllowanceAmounts(AddressAllowanceRequest request, {CallOptions? options}) → ResponseStream<AddressAllowanceAmount>
getAllowanceTokens(AddressAllowanceRequest request, {CallOptions? options}) → ResponseFuture<AddressAllowanceToken>
getTokens(AddressTokenRequest request, {CallOptions? options}) → ResponseFuture<AddressToken>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subscribeAllowanceAmounts(AddressAllowanceRequest request, {CallOptions? options}) → ResponseStream<AddressAllowanceAmount>
subscribeAllowanceTokens(AddressAllowanceRequest request, {CallOptions? options}) → ResponseStream<AddressAllowanceToken>
subscribeTokens(AddressTokenRequest request, {CallOptions? options}) → ResponseStream<AddressToken>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.