TokenServiceBase class abstract

Annotations
  • @GrpcServiceName.new('emerald.Token')

Constructors

TokenServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
getAllowanceAmounts(ServiceCall call, AddressAllowanceRequest request) Stream<AddressAllowanceAmount>
getAllowanceAmounts_Pre(ServiceCall $call, Future<AddressAllowanceRequest> $request) Stream<AddressAllowanceAmount>
getAllowanceTokens(ServiceCall call, AddressAllowanceRequest request) Future<AddressAllowanceToken>
getAllowanceTokens_Pre(ServiceCall $call, Future<AddressAllowanceRequest> $request) Future<AddressAllowanceToken>
getTokens(ServiceCall call, AddressTokenRequest request) Future<AddressToken>
getTokens_Pre(ServiceCall $call, Future<AddressTokenRequest> $request) Future<AddressToken>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subscribeAllowanceAmounts(ServiceCall call, AddressAllowanceRequest request) Stream<AddressAllowanceAmount>
subscribeAllowanceAmounts_Pre(ServiceCall $call, Future<AddressAllowanceRequest> $request) Stream<AddressAllowanceAmount>
subscribeAllowanceTokens(ServiceCall call, AddressAllowanceRequest request) Stream<AddressAllowanceToken>
subscribeAllowanceTokens_Pre(ServiceCall $call, Future<AddressAllowanceRequest> $request) Stream<AddressAllowanceToken>
subscribeTokens(ServiceCall call, AddressTokenRequest request) Stream<AddressToken>
subscribeTokens_Pre(ServiceCall $call, Future<AddressTokenRequest> $request) Stream<AddressToken>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited