AddressTransaction class

Available extensions

Constructors

AddressTransaction({ChainRef? chain, SingleAddress? address, UInt32Value? xpubIndex, String? txId, BlockInfo? block, bool? mempool, String? cursor, bool? removed, bool? failed, Iterable<Change>? changes, int? txIndexInBlock})
factory
AddressTransaction.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
AddressTransaction.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

address SingleAddress
getter/setter pair
block BlockInfo
getter/setter pair
chain ChainRef
getter/setter pair
changes → PbList<Change>
all changes in transaction
no setter
cursor String
N/A for mempool and last blocks (unconfirmed)
getter/setter pair
failed bool
true if transaction is failed
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
mempool bool
getter/setter pair
removed bool
true if transaction is removed from blockchain mempool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
txId String
getter/setter pair
txIndexInBlock int
transaction index in block
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
xpubIndex ↔ UInt32Value
index of address in xpub if xpub has been requested (optional)
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAddress() → void
clearBlock() → void
clearChain() → void
clearCursor() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearFailed() → void
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearMempool() → void
clearRemoved() → void
clearTxId() → void
clearTxIndexInBlock() → void
clearXpubIndex() → void
clone() AddressTransaction
Creates a deep copy of the fields in this message.
copyWith(void updates(AddressTransaction)) AddressTransaction
Apply updates to a copy of this message.
createEmptyInstance() AddressTransaction
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureAddress() SingleAddress
ensureBlock() BlockInfo
ensureXpubIndex() → UInt32Value
extensionsAreInitialized() bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasAddress() bool
hasBlock() bool
hasChain() bool
hasCursor() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasFailed() bool
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasMempool() bool
hasRemoved() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasTxId() bool
hasTxIndexInBlock() bool
hasXpubIndex() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited