TransactionClient class

Annotations
  • @GrpcServiceName.new('emerald.Transaction')

Constructors

TransactionClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
getAddressTx(AddressTxRequest request, {CallOptions? options}) → ResponseStream<AddressTxResponse>
DEPRECATED, replaced by GetTransactions
getTransactions(GetTransactionsRequest request, {CallOptions? options}) → ResponseStream<AddressTransaction>
Get transaction for address
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subscribeAddressTx(AddressTxRequest request, {CallOptions? options}) → ResponseStream<AddressTxResponse>
DEPRECATED, replaced by SubscribeTransactions
subscribeTransactions(SubscribeTransactionsRequest request, {CallOptions? options}) → ResponseStream<AddressTransaction>
Subscribe to new transactions in blocks and all transaction in mempool for address
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.