TransactionServiceBase class abstract

Annotations
  • @GrpcServiceName.new('emerald.Transaction')

Constructors

TransactionServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
getAddressTx(ServiceCall call, AddressTxRequest request) Stream<AddressTxResponse>
getAddressTx_Pre(ServiceCall $call, Future<AddressTxRequest> $request) Stream<AddressTxResponse>
getTransactions(ServiceCall call, GetTransactionsRequest request) Stream<AddressTransaction>
getTransactions_Pre(ServiceCall $call, Future<GetTransactionsRequest> $request) Stream<AddressTransaction>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subscribeAddressTx(ServiceCall call, AddressTxRequest request) Stream<AddressTxResponse>
subscribeAddressTx_Pre(ServiceCall $call, Future<AddressTxRequest> $request) Stream<AddressTxResponse>
subscribeTransactions(ServiceCall call, SubscribeTransactionsRequest request) Stream<AddressTransaction>
subscribeTransactions_Pre(ServiceCall $call, Future<SubscribeTransactionsRequest> $request) Stream<AddressTransaction>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited