AuthClient class

Annotations
  • @GrpcServiceName.new('emerald.Auth')

Constructors

AuthClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
authenticate(AuthRequest request, {CallOptions? options}) → ResponseFuture<AuthResponse>
Get a JWT token to be used for further requests
deleteToken(DeleteTokenRequest request, {CallOptions? options}) → ResponseFuture<DeleteTokenResponse>
Delete token
issueToken(IssueTokenRequest request, {CallOptions? options}) → ResponseFuture<IssuedTokenResponse>
Issue a new secret token (based on the current authentication)
listTokens(ListTokensRequest request, {CallOptions? options}) → ResponseFuture<ListTokensResponse>
List all tokens for the requests organization
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refresh(RefreshRequest request, {CallOptions? options}) → ResponseFuture<AuthResponse>
Refresh an expired JWT token
toString() String
A string representation of this object.
inherited
whoAmI(WhoAmIRequest request, {CallOptions? options}) → ResponseFuture<WhoAmIResponse>
Get the details about the current authentication

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.