TEMP constant
IssueTokenRequest_TokenType
const TEMP
a one-time token that is valid for a short period of time, just a reference to the current token for one time and exclusive session but may be limited by time, scope, etc. expires after first use.
Implementation
static const IssueTokenRequest_TokenType TEMP =
IssueTokenRequest_TokenType._(0, _omitEnumNames ? '' : 'TEMP');