blocks property
How many blocks the server is supposed to use to estimate current fee. Note that the server may use value, depending on configuration
Implementation
@$pb.TagNumber(3)
$core.int get blocks => $_getIZ(2);
Implementation
@$pb.TagNumber(3)
set blocks($core.int value) => $_setUnsignedInt32(2, value);