ChainRef class
Defines standard chain references used across Emerald APIs.
The numbering scheme is as follows:
- Bitcoin starts with 1
- Ethereum starts with 100
- Sidechains and state channels start with 1_000
- All Testnets start with 10_000
- Non-standard chains start with 20_000
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- CHAIN_BITCOIN → const ChainRef
- CHAIN_ETHEREUM → const ChainRef
- CHAIN_ETHEREUM_CLASSIC → const ChainRef
- CHAIN_FANTOM → const ChainRef
- Fantom, https://fantom.foundation/
- CHAIN_GOERLI → const ChainRef
- DEPRECATED, use CHAIN_SEPOLIA instead
- CHAIN_HOLESKY → const ChainRef
- DEPRECATED, use CHAIN_HOODI instead
- CHAIN_HOODI → const ChainRef
- / replaces HOLESKY, / https://github.com/eth-clients/hoodi
- CHAIN_KOVAN → const ChainRef
- DEPRECATED
- CHAIN_MATIC → const ChainRef
- Matic PoS Ethereum sidechain based on Polygon
- CHAIN_MORDEN → const ChainRef
- DEPRECATED
- CHAIN_RINKEBY → const ChainRef
- DEPRECATED, use CHAIN_SEPOLIA instead
- CHAIN_ROPSTEN → const ChainRef
- DEPRECATED, use CHAIN_HOLESKY instead
- CHAIN_RSK → const ChainRef
- RSK sidechain, https://www.rsk.co/
- CHAIN_SEPOLIA → const ChainRef
- / / https://github.com/eth-clients/sepolia
- CHAIN_TESTNET_BITCOIN → const ChainRef
- DEPRECATED, use CHAIN_TESTNET_BITCOIN_4 instead
- CHAIN_TESTNET_BITCOIN_4 → const ChainRef
- https://bips.dev/94/
- CHAIN_UNSPECIFIED → const ChainRef
-
values
→ const List<
ChainRef>